package com.mortals.xhx.feign.dept;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.dept.DeptPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;
/**
 * 部门 Feign接口
 * @author zxfei
 * @date 2022-12-09
 */
@FeignClient(name = "base-manager", path = "/base", fallbackFactory = DeptFeignFallbackFactory.class)
public interface IDeptFeign extends IFeign {


    /**
     * 查看部门列表
     *
     * @param deptPdu
     * @return
     */
    @PostMapping(value = "/dept/list")
    Rest<RespData<List<DeptPdu>>> list(@RequestBody DeptPdu deptPdu);


    /**
     * 查看部门
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/dept/info")
    Rest<DeptPdu> info(@RequestParam(value = "id") Long id);

    /**
     * 删除部门
     *
     * @param ids
     * @return
     */
    @GetMapping(value = "/dept/delete")
    Rest<Void> delete(Long[] ids,@RequestHeader("Authorization") String authorization);


    /**
     * 部门保存更新
     *
     * @param deptPdu
     * @return
     */
    @PostMapping(value = "/dept/save")
    Rest<RespData<DeptPdu>> save(@RequestBody DeptPdu deptPdu,@RequestHeader("Authorization") String authorization);


}


@Slf4j
@Component
class DeptFeignFallbackFactory implements FallbackFactory<IDeptFeign> {
    @Override
    public IDeptFeign create(Throwable t) {
        return new IDeptFeign() {
            @Override
            public Rest<RespData<List<DeptPdu>>> list(DeptPdu deptPdu) {
               return Rest.fail("暂时无法获取部门列表，请稍后再试!");
            }

            @Override
            public Rest<DeptPdu> info(Long id) {
               return Rest.fail("暂时无法获取部门详细，请稍后再试!");
            }

            @Override
            public Rest<Void> delete(Long[] ids, String authorization) {
                return Rest.fail("暂时无法删除部门，请稍后再试!");
            }

            @Override
            public Rest<RespData<DeptPdu>> save(DeptPdu deptPdu, String authorization) {
                return Rest.fail("暂时无法保存部门，请稍后再试!");
            }
        };
    }
}








